@@ -9,7 +9,11 @@
         x <- as.declared (x)
     }
 
-    if (is.null(x) || !is.atomic (x) || !is.numeric (x)) {
+    if (
+        is.null (x) || !(
+            is.atomic (x) && is.numeric (x)
+        )
+    ) {
         stopError_ ("'x' should be an atomic numerical vector.")
     }
 
@@ -30,7 +34,7 @@
     }
 
     if (
-        !is.null(wt) && !(
+        !is.null (wt) && !(
             is.atomic (wt) && all (is.finite (na.omit (wt)))
         )
     ) {
